@@ -18,6 +18,26 @@ def resolve_missing(
     for module in modules:
         LazyLib.import_lib(module)
 
+
+def resolve_missing_custom(
+    modules: typing.Union[str, typing.List],
+    required: bool = True,
+):
+    """
+    Handles custom use cases like `torch` where we need to
+    have a extra index to install from
+    """
+    if not isinstance(modules, list):
+        modules = [modules]
+    module_names = [module.split(' ', 1)[0] for module in modules]
+    kind = 'required' if required else 'optionally required'
+    logger.info(f"{', '.join(module_names)} are {kind}. Installing...")
+    for module in modules:
+        module_name = LazyLib.get_requirement(module, True)
+        if LazyLib.is_available(module_name):
+            continue
+        LazyLib.install_library(module)
+
     
 def require_missing_wrapper(
     resolver: typing.Callable,
